"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeSonarAnalysis = executeSonarAnalysis;
var _child_process = require("child_process");
var _sonarReportSummary = require("./sonarReportSummary");
var _logger = require("../../utils/logger");
var _getSonarProperties = require("./getSonarProperties");
var _getFileUtils = require("../eslint/getFileUtils");
var _fileUtils = require("../../utils/fileUtils");
var _requestUtils = require("../../utils/requestUtils");
/**
 * @note javascript code  to start sonar Server
 */

/**
 * @function executeSonarAnalysis - start sonar analysis and send metric to sonar server
 * @param {Object} cliParams - Object represent cli Argument 
 */

function executeSonarAnalysis(cliParams) {
  var {
    env
  } = cliParams;
  _logger.Logger.createLogFile();
  const command = (0, _getSonarProperties.getSonarProperties)(cliParams);
  const child_process = (0, _child_process.spawn)("java", command);
  _logger.Logger.cliLog("success", "\n Sending report to SonarQube ...");
  child_process.stdout.on("data", data => {
    _logger.Logger.log(_logger.Logger.INFO_TYPE, data.toString());
    _logger.Logger.emit(data);
  });
  child_process.stderr.on("data", errorOut => {
    // error will appear here
    // Logger.error(Logger.FAILURE_TYPE, errorOut);
  });
  child_process.on("error", error => {
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, '\n failed to send report to sonarQube ...');
    _logger.Logger.error(_logger.Logger.FAILURE_TYPE, `Error: ${error.message}`);
  });
  child_process.on("close", code => {
    var {
      branchDiffPath
    } = (0, _fileUtils.getLintConfiguration)();
    code === 0 ? global.analytics.sonarQubeStatus = true : null;
    (0, _sonarReportSummary.writeSummaryOfLint)(cliParams);
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, `\n SonarQube analysis ${code === 0 ? "success" : "failed"} ...`);
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, `\n Report ${code === 0 ? "successfully" : "failed"} sent to the server :  Status - ${code === 0 ? "Success" : "Failure"}`);
    code === 0 ? _logger.Logger.cliLog(_logger.Logger.PATH_TYPE, `\n Report URL - ${(0, _sonarReportSummary.getSummaryOfLint)(cliParams).web_url}`) : null;
    _logger.Logger.cliLog(_logger.Logger.INFO_TYPE, `\n JSON report Path - ${(0, _getFileUtils.getLintReportPath)()}`);
    code === 0 ? _logger.Logger.cliLog(_logger.Logger.INFO_TYPE, `\n SonarQube Artifacts Path - ${(0, _getSonarProperties.getSonarArtifactsDir)()}`) : null;
    const ciCommands = ['lint-ci', 'dev-ci', 'exemption-report', 'precommit'];
    const shouldRemoveFiles = env == 'ci' && ciCommands.includes(cliParams.cmdExecuted);
    ;
    if (shouldRemoveFiles) {
      (0, _getFileUtils.removeFile)(branchDiffPath);
      (0, _getFileUtils.removeFile)((0, _requestUtils.getExemptionFileInfoPath)());
    }
  });
}